==> nextcloud-29.0.12.tgz: nextcloud/apps/files_reminders/l10n/sk.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Pripomienky súborov",
    "Reminder for {name}" : "Pripomienka pre {name}",
    "View file" : "Zobraziť súbor",
    "View folder" : "Zobraziť adresár",
    "Set file reminders" : "Nastaviť pripomienky súborov",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Pripomienky súborov**\n\nNastavte pripomienky súborov.\n\nPoznámka: Ak chcete použiť aplikáciu „Pripomienky súborov“, uistite sa, že je nainštalovaná a povolená aplikácia „Upozornenia“. Aplikácia „Upozornenia“ poskytuje potrebné rozhrania API, aby aplikácia „Pripomienky súborov“ fungovala správne.",
    "We will remind you of this file" : "Pripomenieme vám tento súbor",
    "Please choose a valid date & time" : "Prosím, vyberte platný dátum a čas",
    "Cancel" : "Zrušiť",
    "Clear reminder" : "Vymazať pripomienku",
    "Set reminder" : "Nastaviť pripomienku",
    "Set reminder for \"{fileName}\"" : "Nastaviť pripomienku pre \"{fileName}\"",
    "Set reminder at custom date & time" : "Nastaviť pripomienku na vlastn dátum a čas",
    "Reminder set for \"{fileName}\"" : "Pripomienka nastavená pre \"{fileName}\"",
    "Failed to set reminder" : "Nepodarilo sa nastavit pripomienku",
    "Reminder cleared for \"{fileName}\"" : "Pripomienka pre \"{fileName}\" bola odstránená",
    "Failed to clear reminder" : "Nepodarilo sa odstrániť pripomienku",
    "Reminder set" : "Pripomienka bola nastavená",
    "Set custom reminder" : "Nastaviť vlastnú pripomienku",
    "Later today" : "Neskôr dnes",
    "Set reminder for later today" : "Nastaviť pripomienku na dnes-neskôr.",
    "Tomorrow" : "Zajtra",
    "Set reminder for tomorrow" : "Nastaviť pripomienku na zajtra",
    "This weekend" : "Tento víkend",
    "Set reminder for this weekend" : "Nastaviť pripomienku na tento víkend",
    "Next week" : "Nasledujúci týždeň",
    "Set reminder for next week" : "Nastaviť pripomienku na budúci týždeň"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-31.0.13.tgz: nextcloud/apps/files_reminders/l10n/sk.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Pripomienky súborov",
    "Reminder for {name}" : "Pripomienka pre {name}",
    "View file" : "Zobraziť súbor",
    "View folder" : "Zobraziť adresár",
    "Files reminder" : "Pripomienka súborov",
    "The \"files_reminders\" app can work properly." : "Aplikácia \"files_reminders\" môže fungovať správne.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikácia \"files_reminders\" potrebuje aplikáciu na notifikácie na správne fungovanie. Mali by ste buď povoliť notifikácie, alebo vypnúť aplikáciu files_reminder.",
    "Set file reminders" : "Nastaviť pripomienky súborov",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Pripomienky súborov**\n\nNastavte pripomienky súborov.\n\nPoznámka: Ak chcete použiť aplikáciu „Pripomienky súborov“, uistite sa, že je nainštalovaná a povolená aplikácia „Upozornenia“. Aplikácia „Upozornenia“ poskytuje potrebné rozhrania API, aby aplikácia „Pripomienky súborov“ fungovala správne.",
    "Please choose a valid date & time" : "Prosím, vyberte platný dátum a čas",
    "Reminder set for \"{fileName}\"" : "Pripomienka nastavená pre \"{fileName}\"",
    "Failed to set reminder" : "Nepodarilo sa nastavit pripomienku",
    "Reminder cleared for \"{fileName}\"" : "Pripomienka pre \"{fileName}\" bola odstránená",
    "Failed to clear reminder" : "Nepodarilo sa odstrániť pripomienku",
    "Reminder at custom date & time" : "Pripomienka vo vlastný dátum a čas",
    "We will remind you of this file" : "Pripomenieme vám tento súbor",
    "Cancel" : "Zrušiť",
    "Clear reminder" : "Vymazať pripomienku",
    "Set reminder" : "Nastaviť pripomienku",
    "Set reminder for " : "Nastaviť pripomienku na",
    "Reminder set" : "Pripomienka bola nastavená",
    "Custom reminder" : "Vlastná pripomienka",
    "Later today" : "Neskôr dnes",
    "Set reminder for later today" : "Nastaviť pripomienku na dnes-neskôr.",
    "Tomorrow" : "Zajtra",
    "Set reminder for tomorrow" : "Nastaviť pripomienku na zajtra",
    "This weekend" : "Tento víkend",
    "Set reminder for this weekend" : "Nastaviť pripomienku na tento víkend",
    "Next week" : "Nasledujúci týždeň",
    "Set reminder for next week" : "Nastaviť pripomienku na budúci týždeň",
    "This files_reminder can work properly." : "Tento files_reminder môže správne fungovať.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Aplikácia files_reminder potrebuje aplikáciu na oznámenia na správne fungovanie. Mali by ste buď povoliť oznámenia, alebo vypnúť files_reminder.",
    "Set reminder for \"{fileName}\"" : "Nastaviť pripomienku pre \"{fileName}\"",
    "Set reminder at custom date & time" : "Nastaviť pripomienku na vlastn dátum a čas",
    "Set custom reminder" : "Nastaviť vlastnú pripomienku"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
